@@ -351,7 +351,7 @@ class Configuration:
         self.name = name
         self.__mode = mode
         if parts is None:
-            self.__parts = self.KEYPAD
+            self.__parts = self.FUNCTION
         else:
             self.__parts = parts
 
@@ -533,6 +533,8 @@ class Core(metaclass=SingletonType):
             self.__next_config()
             self.__show_message('配置\n{}'.format(self.__configs[self.__current_config].name))
             return 1
+        elif event.vk_code == self.__switch_key and HookConstants.is_keydown(event.w_param):
+            return 1
 
         # 部分模式下放行所有非快捷区域键盘输入
         config = self.__configs[self.__current_config]
@@ -540,6 +542,7 @@ class Core(metaclass=SingletonType):
             return 0
 
         # 判断按键是否触发相关命令函数
+        inspect_flag = False
         for command in config.commands.values():
             if command.condition.inspect(event):
                 if command.condition.alias is None:
@@ -557,9 +560,10 @@ class Core(metaclass=SingletonType):
                     self.__flag_run = False
 
                 self.__pool.submit(callback)
+                inspect_flag = True
                 break
-            elif HookConstants.is_keyup(event.w_param):
-                self.__show_message('命令\n空')
+        if (not inspect_flag) and HookConstants.is_keyup(event.w_param):
+            self.__show_message('命令\n空')
         return 1
 
     def __show(self, text, duration):
@@ -574,7 +578,7 @@ class Core(metaclass=SingletonType):
         time.sleep(duration)
         self.__window.hide()
 
-    def __show_message(self, text, duration=1):
+    def __show_message(self, text, duration=0.5):
         """
         后台线程运行窗体显示函数
         :param text:
